@@ -43,6 +43,7 @@ from ._dict import (
 )
 from ._helpers import (
     attribute,
+    auto_caller_module,
     dict_attribute,
     dict_cls,
     list_attribute,
@@ -185,6 +186,7 @@ __all__ = [
     "dict_cls",
     "list_cls",
     "set_cls",
+    "auto_caller_module",
     "attribute",
     "dict_attribute",
     "list_attribute",
