@@ -1,5 +1,7 @@
 """Helper functions."""
 
+import functools
+
 import six
 from basicco import caller_module, custom_repr, dynamic_class, fabricate_value
 from basicco.namespace import Namespace
@@ -18,6 +20,62 @@ KT = TypeVar("KT")
 VT = TypeVar("VT")
 
 
+def auto_caller_module(
+    iterable_params=None,  # type: Iterable[str] | str | None
+    single_params=None,  # type: Iterable[str] | str | None
+):
+    # type: (...) -> Callable[[T], T]
+    """
+    Make a decorator for a function that takes iterable/single keyword arguments that contain module paths.
+    If no paths are provided, set the caller module as a path.
+
+    :param iterable_params: Keyword arguments that are supposed to contain module paths.
+    :param single_params: Keyword argument that are supposed to contain a single module path or None.
+    :return: Decorator.
+    """
+    if isinstance(iterable_params, six.string_types):
+        iterable_params = (iterable_params,)
+    elif iterable_params is None:
+        iterable_params = ()
+    else:
+        iterable_params = tuple(iterable_params)
+
+    if isinstance(single_params, six.string_types):
+        single_params = (single_params,)
+    elif single_params is None:
+        single_params = ()
+    else:
+        single_params = tuple(single_params)
+
+    def decorator(func):
+        @functools.wraps(func)
+        def decorated(*args, **kwargs):
+            _iterable_params = []
+            _single_params = []
+            for iterable_param in iterable_params:
+                values = tuple(kwargs.get(iterable_param, ()))
+                if not values:
+                    _iterable_params.append(iterable_param)
+            for single_param in single_params:
+                value = kwargs.get(single_param, None)
+                if value is None:
+                    _single_params.append(single_param)
+
+            if _iterable_params or _single_params:
+                module = caller_module.caller_module()
+                for iterable_param in _iterable_params:
+                    kwargs[iterable_param] = (module,)
+                for single_param in _single_params:
+                    kwargs[single_param] = module
+
+            return func(*args, **kwargs)
+
+        return decorated
+
+    return decorator
+
+
+@auto_caller_module("extra_paths", "cls_module")
 def dict_cls(
     converter=None,  # type: Callable[[Any], VT] | Type[VT] | str | None
     validator=None,  # type: Callable[[Any], None] | str | None
@@ -67,24 +125,8 @@ def dict_cls(
     :return: Dictionary structure class.
     """
 
-    # Caller module.
-    caller_mod = caller_module.caller_module()
-    extra_paths = tuple(tuple(extra_paths) or (m for m in (caller_mod,) if m))
-    if cls_module is None:
-        cls_module = caller_mod
-
     # Relationships.
-    relationship = relationship_type(
-        converter=converter,
-        validator=validator,
-        types=types,
-        subtypes=subtypes,
-        serializer=serializer,
-        extra_paths=extra_paths,
-        builtin_paths=builtin_paths,
-        **(relationship_kwargs or {})  # noqa
-    )
-    key_relationship = key_relationship_type(
+    relationship = key_relationship_type(
         converter=key_converter,
         validator=key_validator,
         types=key_types,
@@ -94,11 +136,21 @@ def dict_cls(
         builtin_paths=builtin_paths,
         **(key_relationship_kwargs or {})  # noqa
     )
+    value_relationship = relationship_type(
+        converter=converter,
+        validator=validator,
+        types=types,
+        subtypes=subtypes,
+        serializer=serializer,
+        extra_paths=extra_paths,
+        builtin_paths=builtin_paths,
+        **(relationship_kwargs or {})  # noqa
+    )
 
     # Class body.
     cls_dct = dict(cls_dct or {})
     cls_dct["relationship"] = relationship
-    cls_dct["key_relationship"] = key_relationship
+    cls_dct["value_relationship"] = value_relationship
 
     # Build class and return it.
     return cast(
@@ -112,6 +164,7 @@ def dict_cls(
     )
 
 
+@auto_caller_module("extra_paths", "cls_module")
 def list_cls(
     converter=None,  # type: Callable[[Any], T] | Type[T] | str | None
     validator=None,  # type: Callable[[Any], None] | str | None
@@ -147,12 +200,6 @@ def list_cls(
     :return: List structure class.
     """
 
-    # Caller module.
-    caller_mod = caller_module.caller_module()
-    extra_paths = tuple(tuple(extra_paths) or (m for m in (caller_mod,) if m))
-    if cls_module is None:
-        cls_module = caller_mod
-
     # Relationship.
     relationship = relationship_type(
         converter=converter,
@@ -181,6 +228,7 @@ def list_cls(
     )
 
 
+@auto_caller_module("extra_paths", "cls_module")
 def set_cls(
     converter=None,  # type: Callable[[Any], T] | Type[T] | str | None
     validator=None,  # type: Callable[[Any], None] | str | None
@@ -216,12 +264,6 @@ def set_cls(
     :return: Set structure class.
     """
 
-    # Caller module.
-    caller_mod = caller_module.caller_module()
-    extra_paths = tuple(tuple(extra_paths) or (m for m in (caller_mod,) if m))
-    if cls_module is None:
-        cls_module = caller_mod
-
     # Relationship.
     relationship = relationship_type(
         converter=converter,
@@ -250,6 +292,7 @@ def set_cls(
     )
 
 
+@auto_caller_module("extra_paths")
 def attribute(
     default=MISSING,  # type: T | MissingType
     factory=MISSING,  # type: Callable[..., T] | str | MissingType
@@ -319,10 +362,6 @@ def attribute(
     :return: Attribute.
     """
 
-    # Caller module.
-    caller_mod = caller_module.caller_module()
-    extra_paths = tuple(tuple(extra_paths) or (m for m in (caller_mod,) if m))
-
     # Build attribute and return it.
     return cast(
         T,
@@ -363,6 +402,7 @@ def attribute(
     )
 
 
+@auto_caller_module("extra_paths", "cls_module")
 def dict_attribute(
     default=MISSING,  # type: Mapping[KT, VT] | MissingType
     factory=MISSING,  # type: Callable[..., Mapping[KT, VT]] | str | MissingType
@@ -405,11 +445,6 @@ def dict_attribute(
     key_relationship_kwargs=None,  # type: Mapping[str, Any] | None
 ):
     # type: (...) -> DictStructure[KT, VT]
-    caller_mod = caller_module.caller_module()
-    extra_paths = tuple(tuple(extra_paths) or (m for m in (caller_mod,) if m))
-    if cls_module is None:
-        cls_module = caller_mod
-
     if not constant and repr is None:
         repr = custom_repr.mapping_repr
 
@@ -445,12 +480,15 @@ def dict_attribute(
             _cb(attr)
 
     def _converter(value, _cls=cls, _conv=converter, _kconv=key_converter):
-        if _conv is not None or _kconv is not None:
-            value = dict(
-                (fabricate_value.fabricate_value(_kconv, k), fabricate_value.fabricate_value(_conv, v))
-                for k, v in six.iteritems(value)
-            )
-        return _cls(value)
+        if isinstance(value, _cls):
+            return value
+        else:
+            if _conv is not None or _kconv is not None:
+                value = dict(
+                    (fabricate_value.fabricate_value(_kconv, k), fabricate_value.fabricate_value(_conv, v))
+                    for k, v in six.iteritems(value)
+                )
+            return _cls(value)
 
     return cast(
         DictStructure[KT, VT],
@@ -489,6 +527,7 @@ def dict_attribute(
     )
 
 
+@auto_caller_module("extra_paths", "cls_module")
 def list_attribute(
     default=MISSING,  # type: Iterable[T] | MissingType
     factory=MISSING,  # type: Callable[..., Iterable[T]] | str | MissingType
@@ -524,11 +563,6 @@ def list_attribute(
     relationship_kwargs=None,  # type: Mapping[str, Any] | None
 ):
     # type: (...) -> ListStructure[T]
-    caller_mod = caller_module.caller_module()
-    extra_paths = tuple(tuple(extra_paths) or (m for m in (caller_mod,) if m))
-    if cls_module is None:
-        cls_module = caller_mod
-
     if not constant and repr is None:
         repr = custom_repr.iterable_repr
 
@@ -557,9 +591,12 @@ def list_attribute(
             _cb(attr)
 
     def _converter(value, _cls=cls, _conv=converter):
-        if _conv is not None:
-            value = [fabricate_value.fabricate_value(_conv, v) for v in value]
-        return _cls(value)
+        if isinstance(value, _cls):
+            return value
+        else:
+            if _conv is not None:
+                value = [fabricate_value.fabricate_value(_conv, v) for v in value]
+            return _cls(value)
 
     return cast(
         ListStructure[T],
@@ -598,6 +635,7 @@ def list_attribute(
     )
 
 
+@auto_caller_module("extra_paths", "cls_module")
 def set_attribute(
     default=MISSING,  # type: Iterable[T] | MissingType
     factory=MISSING,  # type: Callable[..., Iterable[T]] | str | MissingType
@@ -633,11 +671,6 @@ def set_attribute(
     relationship_kwargs=None,  # type: Mapping[str, Any] | None
 ):
     # type: (...) -> SetStructure[T]
-    caller_mod = caller_module.caller_module()
-    extra_paths = tuple(tuple(extra_paths) or (m for m in (caller_mod,) if m))
-    if cls_module is None:
-        cls_module = caller_mod
-
     if not constant and repr is None:
         repr = lambda s: custom_repr.iterable_repr(s, prefix="{", suffix="}")
 
@@ -666,9 +699,12 @@ def set_attribute(
             _cb(attr)
 
     def _converter(value, _cls=cls, _conv=converter):
-        if _conv is not None:
-            value = [fabricate_value.fabricate_value(_conv, v) for v in value]
-        return _cls(value)
+        if isinstance(value, _cls):
+            return value
+        else:
+            if _conv is not None:
+                value = [fabricate_value.fabricate_value(_conv, v) for v in value]
+            return _cls(value)
 
     return cast(
         SetStructure[T],
